==> orpa-node-selenium-webdriver-0.1.4.tgz: package/web-element.js <==

module.exports = function (RED) {
    "use strict";
    var q = require('q');
    var fs = require("fs-extra");
    var easyimg = require("easyimage");
    var verror = require('verror');
    var webdriver = require("selenium-webdriver"),
        By = webdriver.By,
        until = webdriver.until;
    
    console.log('Registering Plugin Service')
    const FinderPluginSvc = require('@torpadev/orpa-page-object-finder').FinderPluginSvc;
    const Dispatcher = require('@torpadev/orpa-page-object-finder').Dispatcher;
    console.log('Registered Plugin Service: Page Object Finder');
    // const finderSvc = new FinderPluginSvc();
    const dispatcher = new Dispatcher();
    dispatcher.registerObject("FinderPluginSvc", FinderPluginSvc);
    // console.log(finderSvc);
    console.log(dispatcher);
    dispatcher.start(9010);
    // RED.comms.publish('object:finder', 'How is the view ?');
    function ConfigureWebPageElements(n) {
        RED.nodes.createNode(this, n);

        this.usecount = 0;

        this.name = n.name;
        this.expression = n.expression;
        this.selector = n.selector;
        this.page = n.page;
        this.markers = n.markers;
        this.framePath = n.framePath;

        var node = this;
        // node.log(n);
        this.register = function () {
            node.usecount += 1;
        };

        this.deregister = function () {
            node.usecount -= 1;
            if (node.usecount == 0) {
            }
        };
    }

    RED.nodes.registerType("web-element", ConfigureWebPageElements);

    RED.httpAdmin.get("/plugins/*",function(req,res) {
        var options = {
            root: __dirname + '/plugins/',
            dotfiles: 'deny'
        };
        res.sendFile(req.params[0], options);
    });
}

==> orpa-node-selenium-webdriver-0.1.5.tgz: package/web-element.js <==

module.exports = function (RED) {
    "use strict";
    var q = require('q');
    var fs = require("fs-extra");
    var easyimg = require("easyimage");
    var verror = require('verror');
    var webdriver = require("selenium-webdriver"),
        By = webdriver.By,
        until = webdriver.until;
    
    // console.log('Registering Plugin Service')
    // const FinderPluginSvc = require('@torpadev/orpa-page-object-finder').FinderPluginSvc;
    // const Dispatcher = require('@torpadev/orpa-page-object-finder').Dispatcher;
    // console.log('Registered Plugin Service: Page Object Finder');
    // // const finderSvc = new FinderPluginSvc();
    // const dispatcher = new Dispatcher();
    // dispatcher.registerObject("FinderPluginSvc", FinderPluginSvc);
    // // console.log(finderSvc);
    // console.log(dispatcher);
    // try{
    //     dispatcher.start(9010);
    // }catch(ex){
    //     console.error(ex);
    // }

    // RED.comms.publish('object:finder', 'How is the view ?');
    function ConfigureWebPageElements(n) {
        RED.nodes.createNode(this, n);

        this.usecount = 0;

        this.name = n.name;
        this.expression = n.expression;
        this.selector = n.selector;
        this.page = n.page;
        this.markers = n.markers;
        this.framePath = n.framePath;

        var node = this;
        // node.log(n);
        this.register = function () {
            node.usecount += 1;
        };

        this.deregister = function () {
            node.usecount -= 1;
            if (node.usecount == 0) {
            }
        };
    }

    RED.nodes.registerType("web-element", ConfigureWebPageElements);

    RED.httpAdmin.get("/plugins/*",function(req,res) {
        var options = {
            root: __dirname + '/plugins/',
            dotfiles: 'deny'
        };
        res.sendFile(req.params[0], options);
    });
}
